@@ -1,7 +1,7 @@
 package App::pmpatcher;
 
-our $DATE = '2016-01-13'; # DATE
-our $VERSION = '0.02'; # VERSION
+our $DATE = '2016-10-10'; # DATE
+our $VERSION = '0.03'; # VERSION
 
 use 5.010001;
 use strict;
@@ -138,9 +138,11 @@ sub pmpatcher {
         # first check if patch is already applied
         system(
             {shell=>1, log=>1, lang=>"C", capture_stdout=>\$out},
-            "patch", "-d", shell_quote($mod_dir),
-            "-t", "--dry-run",
-            "<", shell_quote("$patches_dir/$fname"),
+            join(" ",
+                 "patch", "-d", shell_quote($mod_dir),
+                 "-t", "--dry-run",
+                 "<", shell_quote("$patches_dir/$fname"),
+             ),
         );
 
         if ($?) {
@@ -170,9 +172,11 @@ sub pmpatcher {
                 }
                 system(
                     {shell=>1, log=>1, lang=>"C", capture_stdout=>\$out},
-                    "patch", "-d", shell_quote($mod_dir),
-                    "--reverse",
-                    "<", shell_quote("$patches_dir/$fname"),
+                    join(" ",
+                         "patch", "-d", shell_quote($mod_dir),
+                         "--reverse",
+                         "<", shell_quote("$patches_dir/$fname"),
+                     ),
                 );
                 if ($?) {
                     $log->errorf("Skipping patch '%s' (can't patch(2b) to reverse-apply: %s)",
@@ -196,9 +200,11 @@ sub pmpatcher {
                 }
                 system(
                     {shell=>1, log=>1, lang=>"C", capture_stdout=>\$out},
-                    "patch", "-d", shell_quote($mod_dir),
-                    "--forward",
-                    "<", shell_quote("$patches_dir/$fname"),
+                    join(" ",
+                         "patch", "-d", shell_quote($mod_dir),
+                         "--forward",
+                         "<", shell_quote("$patches_dir/$fname"),
+                     ),
                 );
                 if ($?) {
                     $log->errorf("Skipping patch '%s' (can't patch(2) to apply: %s)",
@@ -237,7 +243,7 @@ App::pmpatcher - Apply a set of module patches on your Perl installation
 
 =head1 VERSION
 
-This document describes version 0.02 of App::pmpatcher (from Perl distribution App-pmpatcher), released on 2016-01-13.
+This document describes version 0.03 of App::pmpatcher (from Perl distribution App-pmpatcher), released on 2016-10-10.
 
 =head1 SYNOPSIS
 
@@ -302,7 +308,7 @@ If you try to run it again, you might get:
 
 There's also a C<--dry-run> and a C<-R> (C<--reverse>) option, just like C<patch>.
 
-This function is not exportable.
+This function is not exported.
 
 This function supports dry-run operation.
 
